Welcome to illico's documentation
=================================

Contents:

.. toctree::
   :maxdepth: 2

   overview
   installation
   usage
   results
   normalization
   out_of_core
   how_it_works
   benchmarks
   contributing
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
